==> cool_location_flutter_plugin-0.0.1.tar.gz: android/src/main/kotlin/com/example/cool_location_flutter_plugin/CoolLocationFlutterPlugin.kt <==
package com.example.cool_location_flutter_plugin

import android.app.Activity
import androidx.annotation.NonNull
import com.example.my_cool_library.CoolLocation

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** CoolLocationFlutterPlugin */
class CoolLocationFlutterPlugin : FlutterPlugin, ActivityAware, MethodCallHandler {

    private lateinit var channel: MethodChannel
    private lateinit var eventChannel: EventChannel
    private var activity: Activity? = null

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        initMethodChannel(flutterPluginBinding)
        initEventChannel(flutterPluginBinding)
    }

    private fun initEventChannel(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        eventChannel = EventChannel(
            flutterPluginBinding.binaryMessenger,
            "native_channel_id_456")

        eventChannel.setStreamHandler(object : EventChannel.StreamHandler {
            override fun onListen(arguments: Any?, eventsSink: EventChannel.EventSink) {
                CoolLocation.getLocationUpdates(every = 1_000) {
                    activity?.runOnUiThread {
                        eventsSink.success(
                            mapOf(
                                "latitude" to it.latitude,
                                "longitude" to it.longitude
                            ))
                    }
                }
            }

            override fun onCancel(arguments: Any?) {
                CoolLocation.stopPeriodicUpdates()
            }

        })
    }

    private fun initMethodChannel(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(
            flutterPluginBinding.binaryMessenger,
            "native_channel_id_123")

        channel.setMethodCallHandler { call, result ->
            when (call.method) {
                "getCurrentLocation" -> {
                    val (latitude, longitude) = CoolLocation.getCurrentLocation()
                    result.success(mapOf("latitude" to latitude, "longitude" to longitude))
                }
                else -> {
                    result.error("1001", "Unknown operation", null)
                }
            }
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "getPlatformVersion") {
            result.success("Android ${android.os.Build.VERSION.RELEASE}")
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
        eventChannel.setStreamHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        activity = null
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivity() {
        activity = null
    }
}

==> cool_location_flutter_plugin-0.0.2.tar.gz: android/src/main/kotlin/com/example/cool_location_flutter_plugin/CoolLocationFlutterPlugin.kt <==
package com.example.cool_location_flutter_plugin

import android.app.Activity
import android.os.Handler
import android.os.Looper
import androidx.annotation.NonNull
import com.example.my_cool_library.CoolLocation

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** CoolLocationFlutterPlugin */
class CoolLocationFlutterPlugin : FlutterPlugin, ActivityAware, MethodCallHandler {

    private lateinit var channel: MethodChannel
    private lateinit var eventChannel: EventChannel
//    private var activity: Activity? = null
    private val handler: Handler = Handler(Looper.getMainLooper())

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        initMethodChannel(flutterPluginBinding)
        initEventChannel(flutterPluginBinding)
    }

    private fun initEventChannel(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        eventChannel = EventChannel(
            flutterPluginBinding.binaryMessenger,
            "native_channel_id_456")

        eventChannel.setStreamHandler(object : EventChannel.StreamHandler {
            override fun onListen(arguments: Any?, eventsSink: EventChannel.EventSink) {
                val duration = arguments as? Int ?: 1_000
                CoolLocation.getLocationUpdates(every = duration.toLong()) {
                    handler.post {
                        eventsSink.success(
                            mapOf(
                                "latitude" to it.latitude,
                                "longitude" to it.longitude
                            ))
                    }
                }
            }

            override fun onCancel(arguments: Any?) {
                CoolLocation.stopPeriodicUpdates()
            }

        })
    }

    private fun initMethodChannel(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(
            flutterPluginBinding.binaryMessenger,
            "native_channel_id_123")

        channel.setMethodCallHandler { call, result ->
            when (call.method) {
                "getCurrentLocation" -> {
                    val (latitude, longitude) = CoolLocation.getCurrentLocation()
                    result.success(mapOf("latitude" to latitude, "longitude" to longitude))
                }
                else -> {
                    result.error("1001", "Unknown operation", null)
                }
            }
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "getPlatformVersion") {
            result.success("Android ${android.os.Build.VERSION.RELEASE}")
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
        eventChannel.setStreamHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        activity = null
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivity() {
        activity = null
    }
}
